@@ -38,13 +38,12 @@ const u32 JControl::SELECTED = 0x00000008;
 
 // Constructor
 JControl::JControl(JControl *_parent, 
-									 u32 _state) : state(_state),
-																 enable(0), disable(0), appear(0), disappear(0),
-																 focus(0), unfocus(0), select(0), unselect(0),
-																 enableData(0), disableData(0), appearData(0), 
-																 disappearData(0),	focusData(0), unfocusData(0), 
-																 selectData(0), unselectData(0),	
-																 focusIndex(++controlCount), parent(_parent)
+									 u32 _state) : parent(_parent), focusIndex(++controlCount), state(_state), 
+																 focus(0), unfocus(0), enable(0), disable(0), appear(0), disappear(0),
+																 select(0), unselect(0), focusData(0), unfocusData(0), 
+																 enableData(0), disableData(0), appearData(0), disappearData(0), 
+																 selectData(0), unselectData(0)
+																 
 {
 	id = controlCount;
 }
@@ -107,6 +106,8 @@ s32 JControl::Update()
       return UpdateDisabled();
     }
   }
+  
+  return state;
 }
 
 // Muestra el control
@@ -197,7 +198,7 @@ void JControl:: Unselect()
   }
 }
 
-u32 JControl::Load(JFile &f)
+u32 JControl::Load(JRW &f)
 {
 	// Carga el ndice de control y del control padre
 	if (0 == f.ReadLE32(&id) ||
@@ -209,7 +210,7 @@ u32 JControl::Load(JFile &f)
 	return 0;
 }
 
-u32 JControl::Save(JFile &f)
+u32 JControl::Save(JRW &f)
 {
 	// Carga el ndice de control y del control padre
 	if (0 == f.WriteLE32(&id) ||
