@@ -47,6 +47,7 @@ JImage * JFont::Printf(JFontRenderType type, JFontAlign align, SDL_Color &fg, SD
 	}
 
 	JImage **img = new JImage*[lines];
+	memset(img, 0, lines*sizeof(JImage*));
 	char *cur = str;
 	s32 line = 0;
 	s32 w = 0, h = 0;
@@ -57,9 +58,21 @@ JImage * JFont::Printf(JFontRenderType type, JFontAlign align, SDL_Color &fg, SD
 		if (*c == '\n' || *(c + 1) == 0)
 		{
 			// New line!
-			if (*(c + 1) != 0)
+			if (*c == '\n')
 				*c = 0;
 			
+			if (!*cur)
+			{
+				// Skip empty strings
+				img[line] = 0;
+				h += LineDistance();
+				++line;
+				cur = c + 1;
+				*c = '\n';
+				++c;
+				continue;
+			}
+
 			switch (type)
 			{
 			default:
@@ -112,7 +125,7 @@ JImage * JFont::Printf(JFontRenderType type, JFontAlign align, SDL_Color &fg, SD
 				break;
 			}
 
-			h += img[line]->Height();
+			h += LineDistance();
 			
 			++line;
 			cur = c + 1;
@@ -131,34 +144,37 @@ JImage * JFont::Printf(JFontRenderType type, JFontAlign align, SDL_Color &fg, SD
 
 	for (line = 0; line < lines; ++line)
 	{
-		switch (align)
+		if (img[line])
 		{
-		case JFONTALIGN_LEFT:
-			x = 0;
-			break;
+			switch (align)
+			{
+			case JFONTALIGN_LEFT:
+				x = 0;
+				break;
+				
+			case JFONTALIGN_RIGHT:
+				x = w - img[line]->Width();
+				break;
+				
+			case JFONTALIGN_CENTER:
+				x = (w - img[line]->Width())/2;
+				break;
+				
+			default:
+				x = 0;
+				break;
+			}
 			
-		case JFONTALIGN_RIGHT:
-			x = w - img[line]->Width();
-			break;
-			
-		case JFONTALIGN_CENTER:
-			x = (w - img[line]->Width())/2;
-			break;
-    
-    default:
-      x = 0;
-      break;
-		}
-			
-		ret->Paste(img[line], 
-							 0, 
-							 0, 
-							 (s32)img[line]->Width(), 
-							 (s32)img[line]->Height(),
-							 x,
-							 (s32)img[line]->Y());
+			ret->Paste(img[line], 
+								 0, 
+								 0, 
+								 (s32)img[line]->Width(), 
+								 (s32)img[line]->Height(),
+								 x,
+								 (s32)img[line]->Y());
 
-		delete img[line];
+			delete img[line];
+		}
 	}
 
 	delete[] img;
