@@ -89,7 +89,7 @@ bool JGLImage::Init(JImage *image, bool withMipmaps)
 	
 	glNewList(listIndex, GL_COMPILE);
 	
-	texture.Bind();
+	texture.GLBind();
 	
 	// 2-3-5-7
 	// |\|\|\| CCW
@@ -98,19 +98,19 @@ bool JGLImage::Init(JImage *image, bool withMipmaps)
 
 	// Bottom left
 	//glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
-	texture.Coord2f(0.0f, th);
+	texture.GLCoord2f(0.0f, th);
 	glVertex3f(-halfW, -halfH, 0.0f);
 
 	// Bottom right
-	texture.Coord2f(tw, th);
+	texture.GLCoord2f(tw, th);
 	glVertex3f(halfW, -halfH, 0.0f);
 
 	// Top left
-	texture.Coord2f(0.0f, 0.0f);
+	texture.GLCoord2f(0.0f, 0.0f);
 	glVertex3f(-halfW, halfH, 0.0f);
 
 	// Top right
-	texture.Coord2f(tw, 0.0f);
+	texture.GLCoord2f(tw, 0.0f);
 	glVertex3f(halfW, halfH, 0.0f);
 
 	glEnd();
