@@ -43,7 +43,7 @@ void JGLMesh::Draw()
       {
         glDisable(GL_COLOR_MATERIAL);
         glEnable(GL_TEXTURE_2D);
-				objects[i].faces[j].material->Texture()->Bind();
+				objects[i].faces[j].material->Texture()->GLBind();
 
 				glBegin(GL_TRIANGLES);
 				glNormal3fv((GLfloat*)&objects[i].vertexNormals[objects[i].faces[j].v1]);
