@@ -40,15 +40,26 @@
 #include <GL/gl.h>
 #include <GL/glu.h>
 
+#ifndef GL_CLAMP_TO_EDGE
+#define GL_CLAMP_TO_EDGE GL_CLAMP
+#endif//GL_CLAMP_TO_EDGE
+
 /** Clase para gestin de texturas
  */
 class JGLTexture : public JObject
 {
-  u32 id;
-  bool hasMipmaps;
-	s32 width;
-	s32 height;
-	s32 bpp;
+	/** Instancia de textura. Sirve para llevar cuenta de las referencias a una misma textura creadas.
+	 */
+	struct JInstance
+	{
+		JInstance() : id(0), refCount(0) {}
+		u32 id;
+		bool hasMipmaps;
+		s32 width;
+		s32 height;
+		s32 bpp;
+		u32 refCount;
+	} *instance;
 
   // Crea la textura.
   u32 Create();
@@ -57,8 +68,14 @@ public:
   // Constructor
   JGLTexture();
 
-  // Destructor
-  ~JGLTexture();
+  // Constructor copia, referencia la textura.
+  JGLTexture(JGLTexture &other);
+
+  // Constructor copia, referencia la textura.
+  JGLTexture(const JGLTexture &other);
+
+	// Determina si esta textura es vlida
+	bool Valid() {return instance != 0;}
 
   // Crea la textura a partir de un buffer.
   u32 Create(JImage *image, bool withMipmaps = true, s32 internalFormat = 4, s32 border = 0, s32 format = GL_RGBA, s32 type = GL_UNSIGNED_BYTE);
@@ -74,34 +91,61 @@ public:
 	static u32 Next2Power(u32 value);
 
   // Devuelve el identificador de textura
-  u32 ID() {return id;}
+  u32 ID() {return instance ? instance->id : 0;}
 
-  // Devuelve la superficie de textura
+  // Devuelve la superficie de textura, debe estar enlazada a OpenGL (bind)
   u8* Data() {u8 *data; glGetTexImage(GL_TEXTURE_2D, 0, GL_RGBA, GL_UNSIGNED_BYTE, data); return data;}
 
   // Devuelve la anchura de la textura
-  u32 Width() {return width;}
+  u32 Width() {return instance->width;}
 
   // Devuelve la altura de la textura
-  u32 Height() {return height;}
+  u32 Height() {return instance->height;}
 
   // Devuelve la profundidad de color
-  u32 BitsPP() {return bpp;}
+  u32 BitsPP() {return instance->bpp;}
 
   // Enlaza la textura a OpenGL
-  void Bind() {glBindTexture(GL_TEXTURE_2D, id);}
+  void GLBind() {glBindTexture(GL_TEXTURE_2D, instance->id);}
+
+  // Establece la repeticin x e y
+  static void GLRepeat() {glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT); glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);}
+
+  // Establece clamp x e y
+  static void GLClamp() {glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP); glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);}
+
+  // Establece clamp to edge x e y
+  static void GLClampToEdge() {glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE); glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);}
+
+  // Establece el parmetro OpenGL dado para las texturas 2D
+  static void GLParameter(u32 param, u32 value) {glTexParameteri(GL_TEXTURE_2D, param, value);}
 
   // Establece las coordenadas de textura
-  void Coord2f(float s, float t) {glTexCoord2f(s, t);}
+  void GLCoord2f(float s, float t) {glTexCoord2f(s, t);}
 
   // Establece las coordenadas de textura
-  void Coord2fv(const float *v) {glTexCoord2fv(v);}
+  void GLCoord2fv(const float *v) {glTexCoord2fv(v);}
 
   // Establece las coordenadas de textura
-  void Coord2d(s32 s, s32 t) {glTexCoord2i(s, t);}
+  void GLCoord2d(s32 s, s32 t) {glTexCoord2i(s, t);}
 
   // Establece las coordenadas de textura
-  void Coord2dv(const s32 *v) {glTexCoord2iv(v);}
+  void GLCoord2dv(const s32 *v) {glTexCoord2iv(v);}
+
+  // Referencia la textura dada.
+  void Ref(JGLTexture &other);
+
+  // Referencia la textura dada.
+	JGLTexture & operator=(JGLTexture &other);
+
+  // Referencia la textura dada.
+  void Ref(const JGLTexture &other);
+
+  // Referencia la textura dada.
+	JGLTexture & operator=(const JGLTexture &other);
+
+  // Destructor
+  virtual ~JGLTexture() {Destroy();}
 };
 
 #endif  // _JGLTEXTURE_INCLUDED
