@@ -32,7 +32,7 @@
 
 #include <JLib/Util/JTypes.h>
 #include <JLib/Math/JVector.h>
-#include <SDL/SDL.h>
+#include <SDL.h>
 #include <GL/gl.h>
 
 /** Vector en pantalla para OpenGL.
