@@ -43,7 +43,7 @@ JImageSprite::JImageSprite(JImageSprite &spr)
 // Si frameW != 0 y frameH != 0, intenta encajarlas en H o V, si no intenta encajar los cuadrados.
 // Si frameW == 0 y frameH == 0 o hay una incoherencia o un error, devuelve false.
 // Si todo va bien, devuelve true.
-bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 numFrames, u32 colorKey)
+bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 _numFrames, u32 colorKey)
 {
 	Destroy();
 	
@@ -54,9 +54,9 @@ bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 n
   if (!img.Load(fileName))
     return false;
 
-  if (numFrames != 0)
+  if (_numFrames != 0)
   {
-    this->numFrames = numFrames;
+    numFrames = _numFrames;
   }
 
   // Para recorrer la imagen
@@ -71,7 +71,7 @@ bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 n
     else
     {
       // Frames en vertical.
-      if (this->numFrames == 0)
+      if (numFrames == 0)
       {
         // Averigua las que caben en la altura de la imagen...
         s32 mod = img.Height() % frameH;
@@ -81,12 +81,12 @@ bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 n
         if (mod != 0)
           return false;
         
-        this->numFrames = numFr;
+        numFrames = numFr;
       }
 
       // Lmites de recorrido de la imagen
       iMax = 1;
-      jMax = this->numFrames;
+      jMax = numFrames;
       frameW = img.Width();
     }
   }
@@ -95,7 +95,7 @@ bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 n
     if (frameH == 0)
     {
       // Frames en horizontal.
-      if (this->numFrames == 0)
+      if (numFrames == 0)
       {
         // Averigua las que caben en la anchura de la imagen...
         s32 mod = img.Width() % frameW;
@@ -105,11 +105,11 @@ bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 n
         if (mod != 0)
           return false;
         
-        this->numFrames = numFr;
+        numFrames = numFr;
       }
 
       // Límites de recorrido de la imagen
-      iMax = this->numFrames;
+      iMax = numFrames;
       jMax = 1;
       frameH = img.Height();
     }
@@ -129,20 +129,20 @@ bool JImageSprite::Load(const JString &fileName, u32 frameW,  u32 frameH,  u32 n
       jMax = img.Height()/frameH;
 
       // Si no se da el nmero de frames se asumen n x m
-      if (this->numFrames == 0)
+      if (numFrames == 0)
       {
-        this->numFrames = iMax * jMax;
+        numFrames = iMax * jMax;
       }
     }
 
-    frames = (JDrawable**)new JImage*[this->numFrames];
+    frames = (JDrawable**)new JImage*[numFrames];
 
     JImage *tmpImg;
 
     // Extrae los frames del sprite de la imagen
-    for (u32 j = 0, count = 0; j < jMax && count < this->numFrames; ++j)
+    for (u32 j = 0, count = 0; j < jMax && count < numFrames; ++j)
     {
-      for (u32 i = 0; i < iMax && count < this->numFrames; ++i, ++count)
+      for (u32 i = 0; i < iMax && count < numFrames; ++i, ++count)
       {
         frames[(j * iMax) + i] = tmpImg = new JImage(frameW, frameH);
         tmpImg->Paste(&img, i * frameW, j * frameH, frameW, frameH);
@@ -359,13 +359,13 @@ void JImageSprite::AdjustSize()
 }
 
 // Carga el sprite.
-u32 JImageSprite::Load(JFile &f)
+u32 JImageSprite::Load(JRW &f)
 {
   if (f.ReadLE32(&fps) &&
       f.ReadLE32(&numFrames) &&
-      f.Read(&loop, sizeof(loop)) &&
-      f.Read(&goBack, sizeof(goBack)) &&
-      f.Read(&backwards, sizeof(backwards)))
+      f.ReadBool(&loop) &&
+      f.ReadBool(&goBack) &&
+      f.ReadBool(&backwards))
   {
     JImage *img;
     s32 xPos, yPos;
@@ -399,10 +399,6 @@ u32 JImageSprite::Load(JFile &f)
 					if (hMax < ((JImage *)frames[i])->Height())
 						hMax = ((JImage *)frames[i])->Height();
 				}
-				else
-				{
-					fprintf(stderr, "Fallo al cargar la imagen %d\n", i);
-				}
       }
     }
 
@@ -429,13 +425,13 @@ u32 JImageSprite::Load(JFile &f)
 }
 
 // Salva el sprite
-u32 JImageSprite::Save(JFile &f)
+u32 JImageSprite::Save(JRW &f)
 {
   if (f.WriteLE32(&fps) &&
       f.WriteLE32(&numFrames) &&
-      f.WriteLE32(&loop) &&
-      f.WriteLE32(&goBack) &&
-      f.WriteLE32(&backwards))
+      f.WriteBool(&loop) &&
+      f.WriteBool(&goBack) &&
+      f.WriteBool(&backwards))
   {
     JImage *img;
     s32 xPos, yPos;
