@@ -35,7 +35,7 @@ JApp * JApp::thisApp = 0;
 JApp::JApp(const JString &strTitle, s32 w, s32 h, bool fullScr, s32 _depth, u32 otherFlags)
  : active(true), paused(false), endLoop(false), title(strTitle), width(w), height(h), depth(_depth), fullScreen(fullScr), 
    doInput(true), flags(otherFlags), appPauseTime(0), keys(0), keyMods(KMOD_NONE), numKeys(0), mouseX(0), mouseY(0), mouseBt(0), 
-   mouseRelX(0), mouseRelY(0), fps(25), dumpVideoInfo(false), soundEnabled(false), iconName(0)
+   mouseRelX(0), mouseRelY(0), joyAxisX(0), joyAxisY(0), joyButton(0), fps(25), dumpVideoInfo(false), soundEnabled(false), iconName(0), screen(0), joystick(0)
 {
   __OnActive = 0;
   __OnKeyUp  = 0;
@@ -89,12 +89,27 @@ bool JApp::Init()
 
   if ( (screen = SDL_SetVideoMode(width, height, depth, flags)) == 0 ) 
   {
-    fprintf(stderr, "No se pudo establecer el modo grfico: %s\n", SDL_GetError());
+    fprintf(stderr, "Error: Couldn't set video mode %s\n", SDL_GetError());
     SDL_Delay(2000);
     SDL_Quit();
     return false;
   }
 
+  if(SDL_NumJoysticks() > 0)
+  {
+    SDL_JoystickEventState(SDL_ENABLE);
+    joystick = SDL_JoystickOpen(0);
+
+    if(!joystick)
+    {
+      fprintf(stderr, "Warning: Joystick not initialized: %s\n", SDL_GetError());
+    }
+  }
+  else
+  {
+    joystick = 0;
+  }
+
 	// Initializes the font subsystem
 	if (!JFont::Init())
 	{
@@ -212,6 +227,20 @@ bool JApp::UpdateEvents()
         break;
 
       case SDL_JOYAXISMOTION:
+        switch(e.jaxis.axis)
+        {
+          case 0:
+            joyAxisX = e.jaxis.value;
+            break;
+
+          case 1:
+            joyAxisY = e.jaxis.value;
+            break;
+
+          default:
+            break;
+        }
+
         if (__OnJoyMove)
         {
           __OnJoyMove(e.jaxis.which, e.jaxis.axis, e.jaxis.value);
@@ -233,6 +262,8 @@ bool JApp::UpdateEvents()
         break;
 
       case SDL_JOYBUTTONDOWN:
+        joyButton = 1;
+
         if (__OnJoyDown)
         {
           __OnJoyDown(e.jbutton.which, e.jbutton.button);
@@ -240,6 +271,8 @@ bool JApp::UpdateEvents()
         break;
 
       case SDL_JOYBUTTONUP:
+        joyButton = 0;
+
         if (__OnJoyUp)
         {
           __OnJoyUp(e.jbutton.which, e.jbutton.button);
