@@ -120,6 +120,9 @@ protected:
 	u8 mouseBt;                     /**< Mouse button mask */
 	s32 mouseRelX;                  /**< Mouse X relative increment */
 	s32 mouseRelY;                  /**< Mouse Y relative increment */
+	s16 joyAxisX;                   /**< Joystick X offset */
+	s16 joyAxisY;                   /**< Joystick Y offset */
+	u8 joyButton;                   /**< Joystick button */
 	JTimer timer;                   /**< Application timer */
 	s32 fps;                        /**< Frames per second */
 	bool dumpVideoInfo;             /**< Must dump video info at init? */
@@ -149,6 +152,7 @@ protected:
   void (*__OnUser)(s32 code, void *data1, void *data2);               /**< User event callback */
 
   SDL_Surface *screen;            /**< Primary surface as of SDL_GetVideoSurface() */
+  SDL_Joystick *joystick;         /**< Joystick device */
 
 public:
   /** Creates the application. The audio mixer must be initialized in the child class.
@@ -404,6 +408,21 @@ public:
 	 */
 	SDLMod KeyMods() {return keyMods;}
 
+	/** Returns the joystick X axis
+	 * @return joystick X axis
+	 */
+	s16 JoystickX() {return joyAxisX;}
+
+	/** Returns the joystick Y axis
+	 * @return joystick Y axis
+	 */
+	s16 JoystickY() {return joyAxisY;}
+
+	/** Returns the joystick buttonstate. Note: It does not differentiate between buttons.
+	 * @return joystick button
+	 */
+	u8 JoystickButton() {return joyButton;}
+
 	/** Updates the given region of the primary surface. If all parameters are 0, 
 	 * the whole window is updated. This is simply a wrapper for SDL_UpdateRect(...).
 	 * @param  x X position of the rectangle to update.
