@@ -13,18 +13,18 @@
  *  Library General Public License for more details.
  * 
  *  You should have received a copy of the GNU Library General Public
- *  License along with this library; if not, write to the Free
+ *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * 
  *  Juan Carlos Seijo Prez
  *  jacob@mainreactor.net
  */
 
-/** Definiciones para compatibilidad entre plataformas.
+/** Definitions for cross-platform compatibility.
  * @file    JCompatibility.h
  * @author  Juan Carlos Seijo Prez
  * @date    09/01/2004
- * @version 0.0.1 - Creacin del fichero - 09/01/2004
+ * @version 0.0.1 - 09/01/2004 - First version.
  */
 
 #ifndef _JCOMPATIBILITY_INCLUDED
@@ -32,10 +32,7 @@
 
 #include <JLib/Util/JTypes.h>
 #ifdef _WIN32
-#define stat        _stat
 #define sleep       _sleep
-#define strdup      _strdup
-#define snprintf    _snprintf
 #define mode_t      u16
 #ifndef S_IFBLK
 #define S_IFBLK     0
