@@ -31,7 +31,7 @@
 
 // Carga una fuente de un fichero Targa, con caracteres de 8x8 pxels,
 // 16 filas y 16 columnas (256). 
-void DumpTGAFontBits(const JString &TGAFileName, const JString &outFileName)
+void JDumpTGAFontBits(const JString &TGAFileName, const JString &outFileName)
 {
   JImage img;
   if (!img.Load(TGAFileName))
@@ -175,7 +175,7 @@ JVideoMode * JListVideoModes(s32 *count, s32 depth)
 			*count = modes.size();
 
 		result = new JVideoMode [modes.size() + 1];
-		for (s32 i = 0; i < modes.size(); ++i)
+		for (u32 i = 0; i < modes.size(); ++i)
 		{
 			memcpy(&result[i], modes[i], sizeof(JVideoMode));
 			delete modes[i];
@@ -194,7 +194,7 @@ JVideoMode * JListVideoModes(s32 *count, s32 depth)
 	return result;
 }
 
-void DumpImage(JImage *img, s32 n)
+void JDumpImage(JImage *img, s32 n)
 {
 	SDL_Surface *s = img->Surface();
 	SDL_PixelFormat *fmt = s->format;
@@ -260,3 +260,4 @@ void DumpImage(JImage *img, s32 n)
 	
 	SDL_UnlockSurface(s);
 }
+
