@@ -87,7 +87,7 @@ bool HCCharacter::Init(JImageSprite *sprites, HCMap *_map, HCRope **_ropes, s32
 	// Sets the hang hotspot at the middle of the largest frame, the width and height 
 	// are half the maximun of either the width or the height
 	s32 max = 0;
-	for (s32 i = 0; i < sprites[HCCS_JUMPLEFT].NumFrames(); ++i)
+	for (u32 i = 0; i < sprites[HCCS_JUMPLEFT].NumFrames(); ++i)
 	{
 		max = (s32)JMax(max, ((JImage *)sprites[HCCS_JUMPLEFT].Frame(i))->Width());
 		max = (s32)JMax(max, ((JImage *)sprites[HCCS_JUMPLEFT].Frame(i))->Height());
@@ -107,13 +107,12 @@ void HCCharacter::MaxJumpRows(s32 newMaxJumpRows)
 	// Simulates a jump to determine the veloccity in Y.
 	s32 curJumpRows = 0;
 	vJumpMax.y = 0.0f;
-	float vx = vJumpMax.x, x = 0.0f, firstVy, lastVy, dy = float(map->CellHeight())/200.0f;
+	float vx = vJumpMax.x, x = 0.0f, firstVy = 0.0f, lastVy = 0.0f, dy = float(map->CellHeight())/200.0f;
 	bool first = true;
 
 	while (curJumpRows <= maxJumpRows)
 	{
 		vJumpMax.y += dy;
-		float xOrg = pos.x, yOrg = pos.y;
 		float vy = -vJumpMax.y, y = 0.0f;
 		vx = vJumpMax.x;
 		x = 0.0f;
@@ -534,12 +533,8 @@ s32 HCCharacter::UpdateHang()
 void HCCharacter::Pos(float x, float y)
 {
 	//	fprintf(stderr, "En Pos() antes pos.x: %f pos.y: %f  v.x: %f v.y: %f  x:%f y:%f  px+vx:%f py+vy:%f\n", pos.x, pos.y, v.x, v.y, x, y, pos.x + v.x, pos.y + v.y);
- MY_LABEL_POSX_EQ_X:
 	pos.x = x;
- MY_LABEL_POSY_EQ_X_END:
- MY_LABEL_POSY_EQ_Y:
 	pos.y = y;
- MY_LABEL_POSY_EQ_Y_END:
 	//	fprintf(stderr, "En Pos() despus pos.x: %f pos.y: %f  v.x: %f v.y: %f  x:%f y:%f\n", pos.x, pos.y, v.x, v.y, x, y);
 	states[state].Pos(x, y);
 }
@@ -875,13 +870,13 @@ void HCCharacter::State(HCCharacterState newState)
 	states[state].Pos(pos.x, pos.y);
 }
 
-u32 HCCharacter::Load(JFile &file)
+u32 HCCharacter::Load(JRW &file)
 {
 	if (0 == file.ReadLE32(&subtype) ||
-			0 == file.ReadLE32(&pos.x) ||
-			0 == file.ReadLE32(&pos.y) ||
-			0 == file.ReadLE32(&vMax.x) ||
-			0 == file.ReadLE32(&vMax.y) ||
+			0 == file.ReadLE32((u32 *)&pos.x) ||
+			0 == file.ReadLE32((u32 *)&pos.y) ||
+			0 == file.ReadLE32((u32 *)&vMax.x) ||
+			0 == file.ReadLE32((u32 *)&vMax.y) ||
 			0 == file.ReadLE32(&maxJumpRows))
 	{
 		fprintf(stderr, "Error reading character's common parameters.\n");
@@ -893,13 +888,13 @@ u32 HCCharacter::Load(JFile &file)
 	return 0;
 }
 
-u32 HCCharacter::Save(JFile &file)
+u32 HCCharacter::Save(JRW &file)
 {
 	if (0 == file.WriteLE32(&subtype) ||
-			0 == file.WriteLE32(&pos.x) ||
-			0 == file.WriteLE32(&pos.y) ||
-			0 == file.WriteLE32(&vMax.x) ||
-			0 == file.WriteLE32(&vMax.y) ||
+			0 == file.WriteLE32((u32 *)&pos.x) ||
+			0 == file.WriteLE32((u32 *)&pos.y) ||
+			0 == file.WriteLE32((u32 *)&vMax.x) ||
+			0 == file.WriteLE32((u32 *)&vMax.y) ||
 			0 == file.WriteLE32(&maxJumpRows))
 	{
 		fprintf(stderr, "Error writing character's common parameters.\n");
