@@ -65,7 +65,6 @@ s32 HCEnemy::Update()
 	Act(actions);
 
 	s32 ret = states[state].Update();
-	s32 row, col;
 
 	UpdateVeloccity();
 	UpdateCollisions();
@@ -129,9 +128,9 @@ s32 HCEnemy::Update()
 	return ret;
 }
 
-u32 HCEnemy::Load(JFile &file, HCTheme &theme, HCMap *_map)
+u32 HCEnemy::Load(JRW &file, HCTheme &theme, HCMap *_map)
 {
-	if (0 == file.ReadLE32(&type) ||
+	if (0 == file.ReadLE32((s32 *)&type) ||
 			0 == file.ReadLE32(&param1) ||
 			0 == file.ReadLE32(&param2) ||
 			0 != HCCharacter::Load(file))
@@ -180,9 +179,9 @@ u32 HCEnemy::Load(JFile &file, HCTheme &theme, HCMap *_map)
 	return 0;
 }
 
-u32 HCEnemy::Save(JFile &file)
+u32 HCEnemy::Save(JRW &file)
 {
-	if (0 == file.WriteLE32(&type) ||
+	if (0 == file.WriteLE32((s32 *)&type) ||
 			0 == file.WriteLE32(&param1) ||
 			0 == file.WriteLE32(&param2) ||
 			0 != HCCharacter::Save(file))
