@@ -37,7 +37,7 @@
 bool HCLoadSaveSlot::Load(s32 slot)
 {
 	// Loads the name of the story and the level number
-	JFile f;
+	JRW f;
 	char name[256];
 
 #ifndef _WIN32
@@ -51,7 +51,7 @@ bool HCLoadSaveSlot::Load(s32 slot)
 	snprintf(name, sizeof(name), HC_DATA_DIR "savedata/slot%02d", slot);
 #endif
 	
-	if (f.Open(name, "rb") && 
+	if (f.Create(name, "rb") && 
 			0 == story.Load(f) &&
 			0 != f.ReadLE32(&level))
 	{
@@ -66,7 +66,7 @@ bool HCLoadSaveSlot::Save(s32 slot, const JString& s, s32 levelNumber)
 	level = levelNumber;
 	story = s;
 
-	JFile f;
+	JRW f;
 	char name[256];
 
 #ifndef _WIN32
@@ -83,7 +83,7 @@ bool HCLoadSaveSlot::Save(s32 slot, const JString& s, s32 levelNumber)
 #endif
 	
 	// Saves the name of the story and the level number
-	if (f.Open(name, "wb"))
+	if (f.Create(name, "wb"))
 	{
 		if (0 == story.Save(f))
 		{
