@@ -35,6 +35,7 @@ HCMap::HCMap()
 	rows = cols = cellWidth = cellHeight = 0;
 	width = height = 0;
 	exitRow = exitCol = 0;
+	linkCells = 0;
 	
 	//gravity = 0.7f;
 	gravity = 0.9f;
@@ -60,12 +61,12 @@ bool HCMap::Init(HCTheme &_theme)
 
 s32 HCMap::Update()
 {
-	for (s32 j = 0; j < rows; ++j)
+	HCMapCell *mc = linkCells;
+
+	while (mc)
 	{
-		for (s32 i = 0; i < cols; ++i)
-		{
-			cells[j][i]->Update();
-		}
+		mc->cell->Update();
+		mc = mc->next;
 	}
 
   return 1;
@@ -73,12 +74,12 @@ s32 HCMap::Update()
 
 void HCMap::Draw()
 {
-	for (s32 j = 0; j < rows; ++j)
+	HCMapCell *mc = linkCells;
+
+	while (mc)
 	{
-		for (s32 i = 0; i < cols; ++i)
-		{
-			cells[j][i]->Draw();
-		}
+		mc->cell->Draw();
+		mc = mc->next;
 	}
 }
 
@@ -273,6 +274,8 @@ void HCMap::Resize(s32 newRows, s32 newCols, bool growRight, bool growDown)
 	height = cellHeight * rows;
 	
 	Pos(pos.x, pos.y);
+	
+	BuildCellLinkList();
 }
 
 void HCMap::Destroy()
@@ -293,6 +296,8 @@ void HCMap::Destroy()
     delete[] cells;
     cells = 0;
   }
+	
+	DestroyCellLinkList();
 }
 
 void HCMap::BuildContFloorOnce(s32 row, s32 col)
@@ -324,13 +329,65 @@ void HCMap::BuildContFloor(s32 row, s32 col)
 	BuildContFloorOnce(row + 1, col + 1);
 }
 
-u32 HCMap::Load(JFile &f)
+void HCMap::BuildCellLinkList()
+{
+	DestroyCellLinkList();
+
+	HCMapCell *mc = 0, *mcOld = 0;
+
+	for (s32 row = 0; row < rows; ++row)
+	{
+		for (s32 col = 0; col < cols; ++col)
+		{
+			if (cells[row][col]->Type() != HCCELLTYPE_BLANK)
+			{
+				mc = new HCMapCell;
+				mc->cell = cells[row][col];
+
+				if (mcOld)
+				{
+					mcOld->next = mc;
+				}
+
+				if (!linkCells)
+				{
+					linkCells = mc;
+				}
+        
+        mcOld = mc;
+			}
+		} 
+	}
+	
+	if (mc)
+	{
+		mc->next = 0;
+	}
+}
+
+void HCMap::DestroyCellLinkList()
+{
+	if (0 != linkCells)
+	{
+		HCMapCell *mc = linkCells, *tmp;
+
+		while (mc)
+		{
+			tmp = mc->next;
+			delete mc;
+			mc = tmp;
+		}
+		
+		linkCells = 0;
+	}
+}
+
+u32 HCMap::Load(JRW &f)
 {
 	Destroy();
-	s32 startRow, startCol;
 
 	// Loads the number of rows and cols, etc.
-	if (0 == f.ReadLE32(&gravity) ||
+	if (0 == f.ReadLE32((u32 *)&gravity) ||
 			0 == f.ReadLE32(&rows) ||
 			0 == f.ReadLE32(&cols) ||
 			0 == f.ReadLE32(&exitRow) ||
@@ -406,14 +463,16 @@ u32 HCMap::Load(JFile &f)
 				BuildContFloor(row, col);
 		}
 	}
+	
+	BuildCellLinkList();
 
 	return 0;
 }
 
-u32 HCMap::Save(JFile &f)
+u32 HCMap::Save(JRW &f)
 {
 	// Saves the number of rows and cols, etc.
-	if (0 == f.WriteLE32(&gravity) ||
+	if (0 == f.WriteLE32((u32 *)&gravity) ||
 			0 == f.WriteLE32(&rows) ||
 			0 == f.WriteLE32(&cols) ||
 			0 == f.WriteLE32(&exitRow) ||
