@@ -75,13 +75,15 @@ bool HCObject::Init(HCTheme *theme)
 	acquired.Destroy();
 	normal.Ref(theme->Object(subtype)[HCODT_NORMAL]);
 	acquired.Ref(theme->Object(subtype)[HCODT_ACQUIRED]);
+  
+  return true;
 }
 
-u32 HCObject::Load(JFile &file)
+u32 HCObject::Load(JRW &file)
 {
 	if (0 == file.ReadLE32(&subtype) ||
-			0 == file.ReadLE32(&pos.x) ||
-			0 == file.ReadLE32(&pos.y))
+			0 == file.ReadLE32((u32 *)&pos.x) ||
+			0 == file.ReadLE32((u32 *)&pos.y))
 	{
 		fprintf(stderr, "Error loading the object.\n");
 			
@@ -93,11 +95,11 @@ u32 HCObject::Load(JFile &file)
 	return 0;
 }
 
-u32 HCObject::Save(JFile &file)
+u32 HCObject::Save(JRW &file)
 {
 	if (0 == file.WriteLE32(&subtype) ||
-			0 == file.WriteLE32(&pos.x) ||
-			0 == file.WriteLE32(&pos.y))
+			0 == file.WriteLE32((u32 *)&pos.x) ||
+			0 == file.WriteLE32((u32 *)&pos.y))
 	{
 		fprintf(stderr, "Error saving the object.\n");
 			
