@@ -179,7 +179,7 @@ s32 HCPreferences::Load(const char *filename)
 	BPP(bpp);
 	fullscreen = (fullscreen != 0) ? true : false;
 	sound = (sound != 0) ? true : false;
-	JClamp(difficulty, HCPREFERENCES_HARD, HCPREFERENCES_EASY);
+	JClamp(difficulty, HCPREFERENCES_HARD, HCPREFERENCES_TOY);
 
 	return 0;
 }
