@@ -41,7 +41,7 @@ bool HCRope::Init(float p, s32 a, u32 l, HCTheme &theme)
 	amplitude = abs(a) < length * theme.Rope(subtype)[HCRDT_MIDDLE].Height() ? abs(a) : length * theme.Rope(subtype)[HCRDT_MIDDLE].Height();
 
 	s32 i;
-	float x = pos.x, y;
+	float y;
 
 	JDELETE_ARRAY(middle);
 	middle = new JImage [length];
@@ -53,12 +53,12 @@ bool HCRope::Init(float p, s32 a, u32 l, HCTheme &theme)
 	{
 		middle[i].Ref(theme.Rope(subtype)[HCRDT_MIDDLE]);
 		y = top.Y() + top.Height() + (i * middle[i].Height());
-		middle[i].Pos(top.X() + (top.Width()/2) - (middle[i].Width()/2), y);
+		middle[i].Pos(top.X() + (top.Width()/2) - (middle[i].Width()/2), pos.y);
 	}
 	
 	edge.Ref(theme.Rope(subtype)[HCRDT_EDGE]);
 	y = top.Y() + top.Height() + (i * middle[0].Height());
-	edge.Pos(top.X() + (top.Width()/2) - (edge.Width()/2), y);
+	edge.Pos(top.X() + (top.Width()/2) - (edge.Width()/2), pos.y);
 
 	// 25 fps resolution
 	timer.Start(40);
@@ -108,6 +108,7 @@ void HCRope::Pos(float x, float y)
 	float dx, dy;
 	dx = x - pos.x;
 	dy = y - pos.y;
+
 	pos.x = x;
 	pos.y = y;
 
@@ -124,14 +125,14 @@ void HCRope::Pos(float x, float y)
 	top.Y(y);
 }
 
-u32 HCRope::Load(JFile &file)
+u32 HCRope::Load(JRW &file)
 {
-	if (0 == file.ReadLE32(&period) ||
+	if (0 == file.ReadLE32((u32 *)&period) ||
 			0 == file.ReadLE32(&amplitude) ||
 			0 == file.ReadLE32(&length) ||
 			0 == file.ReadLE32(&subtype) ||
-			0 == file.ReadLE32(&pos.x) ||
-			0 == file.ReadLE32(&pos.y))
+			0 == file.ReadLE32((u32 *)&pos.x) ||
+			0 == file.ReadLE32((u32 *)&pos.y))
 	{
 		fprintf(stderr, "Error reading rope parameters.\n");
 		
@@ -141,7 +142,7 @@ u32 HCRope::Load(JFile &file)
 	return 0;
 }
 
-u32 HCRope::Load(JFile &file, HCTheme &theme)
+u32 HCRope::Load(JRW &file, HCTheme &theme)
 {
 	if (0 != Load(file))
 	{
@@ -158,14 +159,14 @@ u32 HCRope::Load(JFile &file, HCTheme &theme)
 	return 0;
 }
 
-u32 HCRope::Save(JFile &file)
+u32 HCRope::Save(JRW &file)
 {
-	if (0 == file.WriteLE32(&period) ||
+	if (0 == file.WriteLE32((u32 *)&period) ||
 			0 == file.WriteLE32(&amplitude) ||
 			0 == file.WriteLE32(&length) ||
 			0 == file.WriteLE32(&subtype) ||
-			0 == file.WriteLE32(&pos.x) ||
-			0 == file.WriteLE32(&pos.y))
+			0 == file.WriteLE32((u32 *)&pos.x) ||
+			0 == file.WriteLE32((u32 *)&pos.y))
 	{
 		fprintf(stderr, "Error writing rope parameters.\n");
 		
