@@ -423,7 +423,10 @@ bool HCApp::InitMenu()
 		if (f.ReadLine(str)) it->AddNodeGo(new JTextMenuEntry(str, 0, 0)); else return false;                  //  Difficulty
 		{
 			if (f.ReadLine(str))                                                                                 //   Easy
-				it->AddBranchGo(new JTextMenuEntry(str, &OnDifficulty, (void*)HCPREFERENCES_EASY)); 
+				it->AddBranchGo(new JTextMenuEntry(str, &OnDifficulty, (void*)HCPREFERENCES_TOY)); 
+			else return false;
+			if (f.ReadLine(str))                                                                                 //   Easy
+				it->AddNodeGo(new JTextMenuEntry(str, &OnDifficulty, (void*)HCPREFERENCES_EASY)); 
 			else return false;
 			if (f.ReadLine(str))                                                                                 //   Medium
 				it->AddNodeGo(new JTextMenuEntry(str, &OnDifficulty, (void*)HCPREFERENCES_NORMAL)); 
@@ -761,11 +764,11 @@ bool HCApp::InitCredits()
 
 	const char *strings[HCCREDITS_TEXT_COUNT] = {"Programming\nJuan Carlos Seijo Pérez",
 																							 "Story\nJuan Carlos Seijo Pérez",
-																							 "Drawing\nJuan Carlos Seijo Pérez",
+																							 "Graphics\nJuan Carlos Seijo Pérez",
 																							 "Animation\nJuan Carlos Seijo Pérez",
 																							 "Music\nJuan Carlos Seijo Pérez",
 																							 "Thanks for playing!\nCheck for more games at\nwww.mainreactor.net\n&\nwww.FatalFun.com",
-																							 "Holotz's Castle\n(C) Juan Carlos Seijo Pérez 2004-2007",
+																							 "Holotz's Castle\n(C) Juan Carlos Seijo Pérez 2004-2009",
 																							 ACKNOWLEDGEMENTS};
 
 	bool ok;
@@ -842,7 +845,7 @@ bool HCApp::InitCredits()
 	// Adjusts initial Y
 	textCredits[HCCREDITS_ACK_TEXT]->Y(height);
 
-	imgCredits[HCCREDITS_PROGRAMMING]->Y(textCredits[HCCREDITS_ACK_TEXT]->Y() + (2 * textCredits[HCCREDITS_ACK_TEXT]->Height()));
+	imgCredits[HCCREDITS_PROGRAMMING]->Y(textCredits[HCCREDITS_ACK_TEXT]->Y() + textCredits[HCCREDITS_ACK_TEXT]->Height() + Height()/2);
 	textCredits[HCCREDITS_PROGRAMMING_TEXT]->Y(imgCredits[HCCREDITS_PROGRAMMING]->Y() + imgCredits[HCCREDITS_PROGRAMMING]->Height());
 
 	imgCredits[HCCREDITS_STORY]->Y(imgCredits[HCCREDITS_PROGRAMMING]->Y() + (2 * imgCredits[HCCREDITS_PROGRAMMING]->Height()));
@@ -1014,7 +1017,7 @@ void HCApp::OnSound(void *data)
 	else
 	{
 		a->musicMainTitle.Halt();
-		a->preferences.Sound(true);
+		a->preferences.Sound(false);
 		a->preferences.Save();
 	}
 }
@@ -1315,27 +1318,27 @@ bool HCApp::UpdatePlaying()
 
 	if (level.LevelExit()->State() < HCEXITSTATE_SWALLOWING)
 	{
-		if (Keys()[SDLK_LEFT])
+		if (Keys()[SDLK_LEFT] || JoystickX() < -3000)
 		{
 			actions |= HCCA_LEFT;
 		}
 		else
-		if (Keys()[SDLK_RIGHT])
+		if (Keys()[SDLK_RIGHT] || JoystickX() > 3000)
 		{
 			actions |= HCCA_RIGHT;
 		}
 
-		if (Keys()[SDLK_UP])
+		if (Keys()[SDLK_UP] || JoystickY() < -3000)
 		{
 			actions |= HCCA_UP;
 		}
 		else
-		if (Keys()[SDLK_DOWN])
+		if (Keys()[SDLK_DOWN] || JoystickY() > 3000)
 		{
 			actions |= HCCA_DOWN;
 		}
 
-		if (Keys()[SDLK_SPACE])
+		if (Keys()[SDLK_SPACE] || JoystickButton())
 		{
 			actions |= HCCA_JUMP;
 		}
